summaryrefslogtreecommitdiffstats
path: root/src/kernel/tqasyncimageio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/tqasyncimageio.cpp')
-rw-r--r--src/kernel/tqasyncimageio.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/kernel/tqasyncimageio.cpp b/src/kernel/tqasyncimageio.cpp
index 56126b3d8..f4a144c1b 100644
--- a/src/kernel/tqasyncimageio.cpp
+++ b/src/kernel/tqasyncimageio.cpp
@@ -43,7 +43,7 @@
#ifndef TQT_NO_ASYNC_IMAGE_IO
#include "tqptrlist.h"
-#include "ntqgif.h"
+#include "tqgif.h"
#include <stdlib.h>
extern void tqt_init_image_handlers();
@@ -178,7 +178,7 @@ extern void tqt_init_image_plugins();
\legalese
TQt supports GIF reading if it is configured that way during
- installation (see ntqgif.h). If it is, we are required to state that
+ installation (see tqgif.h). If it is, we are required to state that
"The Graphics Interchange Format(c) is the Copyright property of
CompuServe Incorporated. GIF(sm) is a Service Mark property of
CompuServe Incorporated."
@@ -199,7 +199,7 @@ static const int max_header = 32;
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
class TQGIFFormat : public TQImageFormat {
public:
@@ -299,7 +299,7 @@ public:
{
if ( !factories ) {
factories = new TQPtrList<TQImageFormatType>;
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
gif_decoder_factory = new TQGIFFormatType;
#endif
@@ -310,7 +310,7 @@ public:
static TQPtrList<TQImageFormatType> * factories;
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
static TQGIFFormatType * gif_decoder_factory;
#endif
@@ -320,7 +320,7 @@ public:
};
TQPtrList<TQImageFormatType> * TQImageDecoderPrivate::factories = 0;
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
TQGIFFormatType * TQImageDecoderPrivate::gif_decoder_factory = 0;
#endif
@@ -330,7 +330,7 @@ void TQImageDecoderPrivate::cleanup()
{
delete factories;
factories = 0;
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
delete gif_decoder_factory;
gif_decoder_factory = 0;
@@ -659,7 +659,7 @@ bool qt_builtin_gif_reader()
#endif
}
// See ntqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
/* -- NOTDOC
@@ -199,7 +199,7 @@ static const int max_header = 32;
CompuServe Incorporated."
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
class TQGIFFormat : public TQImageFormat {
@@ -299,7 +299,7 @@ public:
if ( !factories ) {
factories = new TQPtrList<TQImageFormatType>;
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
gif_decoder_factory = new TQGIFFormatType;
@@ -310,7 +310,7 @@ public:
static TQPtrList<TQImageFormatType> * factories;
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
static TQGIFFormatType * gif_decoder_factory;
@@ -320,7 +320,7 @@ public:
};
TQPtrList<TQImageFormatType> * TQImageDecoderPrivate::factories = 0;
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
TQGIFFormatType * TQImageDecoderPrivate::gif_decoder_factory = 0;
@@ -330,7 +330,7 @@ void TQImageDecoderPrivate::cleanup()
delete factories;
factories = 0;
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
delete gif_decoder_factory;
@@ -659,7 +659,7 @@ bool qt_builtin_gif_reader()
#endif
}
-// See ntqgif.h for important information regarding this option
+// See tqgif.h for important information regarding this option
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
/* -- NOTDOC